@@ -28,6 +28,8 @@ class DataSource:
         self.description = kwargs.get('description')
         self.platforms = kwargs.get('x_mitre_platforms')
         self.collection_layers = kwargs.get('x_mitre_collection_layers')
+        self.attack_spec_version = kwargs.get('x_mitre_attack_spec_version')
+        self.domains = kwargs.get('x_mitre_domains')
         self.references = enterpriseattack.utils.obtain_sources(
             kwargs.get('external_references')
         )
@@ -79,8 +81,13 @@ class DataSource:
                     if self.relationships.get(component.id):
                         for r_id in self.relationships.get(component.id):
                             if self.id_lookup.get(r_id):
-                                if (self.id_lookup.get(r_id).get('type') == 'attack-pattern' and
-                                        not self.id_lookup.get(r_id).get('x_mitre_is_subtechnique')):
+                                if (
+                                    self.id_lookup.get(r_id).get('type')
+                                        == 'attack-pattern'
+                                        and not self.id_lookup.get(r_id).get(
+                                            'x_mitre_is_subtechnique'
+                                            )
+                                        ):
                                     techniques_.append(
                                         Technique(
                                             self.attack_objects,
@@ -113,8 +120,12 @@ class DataSource:
                 "collection_layers": self.collection_layers,
                 "references": self.references,
                 "contributor": self.contributors,
-                "techniques": [technique.name for technique in self.techniques],
-                "components": [component.name for component in self.components],
+                "techniques": [
+                    technique.name for technique in self.techniques
+                ],
+                "components": [
+                    component.name for component in self.components
+                ],
                 "deprecated": self.deprecated,
                 "revoked": self.revoked
             }
